@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "helm-taskswitch" "1.0.4"
+(define-package "helm-taskswitch" "20250805.2318"
   "Use helm to switch windows and buffers."
   '((emacs "24")
     (helm  "3.0"))
   :url "https://github.com/bdc34/helm-taskswitch"
-  :commit "de494738f8e5f7d6e681199dd3aad91e5bdb7691"
-  :revdesc "de494738f8e5"
-  :keywords '("desktop" "windows")
+  :commit "11e84316b9db96b19bf1d4038e85bbc26017f302"
+  :revdesc "11e84316b9db"
+  :keywords '("frames")
   :authors '(("Brian Caruso" . "briancaruso@gmail.com"))
   :maintainers '(("Brian Caruso" . "briancaruso@gmail.com")))
